@@ -35,7 +35,6 @@ import org.apache.maven.plugin.descriptor.MojoDescriptor;
 import org.apache.maven.plugin.descriptor.PluginDescriptor;
 import org.apache.maven.plugin.descriptor.Requirement;
 import org.apache.maven.project.MavenProject;
-import org.apache.maven.tools.plugin.DefaultPluginToolsRequest;
 import org.apache.maven.tools.plugin.ExtendedMojoDescriptor;
 import org.apache.maven.tools.plugin.PluginToolsRequest;
 import org.apache.maven.tools.plugin.annotations.datamodel.ComponentAnnotationContent;
@@ -70,6 +69,7 @@ import java.util.TreeSet;
 
 /**
  * JavaMojoDescriptorExtractor, a MojoDescriptor extractor to read descriptors from java classes with annotations.
+ * Notice that source files are also parsed to get description, since and deprecation information.
  *
  * @author Olivier Lamy
  * @since 3.0
@@ -92,12 +92,6 @@ public class JavaAnnotationsMojoDescriptorExtractor
     @org.codehaus.plexus.component.annotations.Requirement
     private ArchiverManager archiverManager;
 
-    public List<MojoDescriptor> execute( MavenProject project, PluginDescriptor pluginDescriptor )
-        throws ExtractionException, InvalidPluginDescriptorException
-    {
-        return execute( new DefaultPluginToolsRequest( project, pluginDescriptor ) );
-    }
-
     public List<MojoDescriptor> execute( PluginToolsRequest request )
         throws ExtractionException, InvalidPluginDescriptorException
     {
@@ -192,13 +186,7 @@ public class JavaAnnotationsMojoDescriptorExtractor
 
     private boolean isMojoAnnnotatedClassCandidate( MojoAnnotatedClass mojoAnnotatedClass )
     {
-        if ( mojoAnnotatedClass == null )
-        {
-            return false;
-        }
-        return ( !mojoAnnotatedClass.getComponents().isEmpty() || !mojoAnnotatedClass.getParameters().isEmpty()
-            || mojoAnnotatedClass.getExecute() != null || mojoAnnotatedClass.getMojo() != null );
-
+        return mojoAnnotatedClass != null && mojoAnnotatedClass.hasAnnotations();
     }
 
     protected Map<String, JavaClass> discoverClassesFromSourcesJar( Artifact artifact, PluginToolsRequest request,
@@ -504,13 +492,7 @@ public class JavaAnnotationsMojoDescriptorExtractor
 
             mojoDescriptor.setInheritedByDefault( mojo.inheritByDefault() );
 
-            String instantiationStrategy = mojo.instantiationStrategy().id();
-            if ( instantiationStrategy == null )
-            {
-                /* Perhaps the original spelling is there. */
-                instantiationStrategy = mojo.instanciationStrategy().id();
-            }
-            mojoDescriptor.setInstantiationStrategy( instantiationStrategy );
+            mojoDescriptor.setInstantiationStrategy( mojo.instantiationStrategy().id() );
 
             mojoDescriptor.setAggregator( mojo.aggregator() );
             mojoDescriptor.setDependencyResolutionRequired( mojo.requiresDependencyResolution().id() );
@@ -550,7 +532,10 @@ public class JavaAnnotationsMojoDescriptorExtractor
             {
                 org.apache.maven.plugin.descriptor.Parameter parameter =
                     new org.apache.maven.plugin.descriptor.Parameter();
-                parameter.setName( parameterAnnotationContent.getFieldName() );
+                String name =
+                    StringUtils.isEmpty( parameterAnnotationContent.name() ) ? parameterAnnotationContent.getFieldName()
+                                    : parameterAnnotationContent.name();
+                parameter.setName( name );
                 parameter.setAlias( parameterAnnotationContent.alias() );
                 parameter.setDefaultValue( parameterAnnotationContent.defaultValue() );
                 parameter.setDeprecated( parameterAnnotationContent.getDeprecated() );
@@ -594,7 +579,10 @@ public class JavaAnnotationsMojoDescriptorExtractor
                 }
                 else
                 {
-                    // not a component but a Maven object to be transformed into an expression/property
+                    // not a component but a Maven object to be transformed into an expression/property: deprecated
+                    getLogger().warn( "Deprecated @component for " + parameter.getName() + " field in "
+                                          + mojoAnnotatedClass.getClassName() + "."
+                                          + ": replace with @parameter name=\"" + expression + "\" @readonly" );
                     parameter.setDefaultValue( expression );
                     parameter.setType( componentAnnotationContent.getRoleClassName() );
                     parameter.setRequired( true );
@@ -619,7 +607,6 @@ public class JavaAnnotationsMojoDescriptorExtractor
     protected ExecuteAnnotationContent findExecuteInParentHierarchy( MojoAnnotatedClass mojoAnnotatedClass,
                                                                      Map<String, MojoAnnotatedClass> mojoAnnotatedClasses )
     {
-
         if ( mojoAnnotatedClass.getExecute() != null )
         {
             return mojoAnnotatedClass.getExecute();
