@@ -41,7 +41,6 @@ import org.apache.maven.project.MavenProject;
 import org.apache.maven.tools.plugin.ExtendedMojoDescriptor;
 import org.apache.maven.tools.plugin.PluginToolsRequest;
 import org.apache.maven.tools.plugin.util.PluginUtils;
-import org.codehaus.plexus.logging.Logger;
 import org.codehaus.plexus.util.IOUtil;
 import org.codehaus.plexus.util.StringUtils;
 import org.codehaus.plexus.util.xml.PrettyPrintXMLWriter;
@@ -51,7 +50,7 @@ import org.codehaus.plexus.util.xml.XMLWriter;
  * Generate a <a href="/ref/current/maven-plugin-api/plugin.html">Maven Plugin Descriptor XML file</a> and
  * corresponding <code>plugin-help.xml</code> help content for {@link PluginHelpGenerator}.
  *
- * @version $Id: PluginDescriptorGenerator.java 1406615 2012-11-07 13:26:25Z krosenvold $
+ * @version $Id: PluginDescriptorGenerator.java 1575558 2014-03-08 16:32:05Z hboutemy $
  * @todo add example usage tag that can be shown in the doco
  * @todo need to add validation directives so that systems embedding maven2 can
  * get validation directives to help users in IDEs.
@@ -164,10 +163,7 @@ public class PluginDescriptorGenerator
             {
                 @SuppressWarnings( "unchecked" ) List<MojoDescriptor> descriptors = pluginDescriptor.getMojos();
 
-                if ( helpDescriptor )
-                {
-                    PluginUtils.sortMojos( descriptors );
-                }
+                PluginUtils.sortMojos( descriptors );
 
                 for ( MojoDescriptor descriptor : descriptors )
                 {
