@@ -29,10 +29,8 @@ import org.apache.maven.plugin.descriptor.InvalidParameterException;
 import org.apache.maven.plugin.descriptor.InvalidPluginDescriptorException;
 import org.apache.maven.plugin.descriptor.MojoDescriptor;
 import org.apache.maven.plugin.descriptor.Parameter;
-import org.apache.maven.plugin.descriptor.PluginDescriptor;
 import org.apache.maven.plugin.descriptor.Requirement;
 import org.apache.maven.project.MavenProject;
-import org.apache.maven.tools.plugin.DefaultPluginToolsRequest;
 import org.apache.maven.tools.plugin.ExtendedMojoDescriptor;
 import org.apache.maven.tools.plugin.PluginToolsRequest;
 import org.apache.maven.tools.plugin.extractor.MojoDescriptorExtractor;
@@ -58,7 +56,7 @@ import java.util.TreeMap;
  *
  * @todo need to add validation directives so that systems embedding maven2 can
  * get validation directives to help users in IDEs.
- * @version $Id: JavaMojoDescriptorExtractor.java 1353231 2012-06-24 08:36:58Z hboutemy $
+ * @version $Id: JavaMojoDescriptorExtractor.java 1592247 2014-05-03 16:38:36Z hboutemy $
  * @see org.apache.maven.plugin.descriptor.MojoDescriptor
  */
 @Component( role = MojoDescriptorExtractor.class, hint = "java" )
@@ -540,6 +538,9 @@ public class JavaMojoDescriptorExtractor
                 else
                 {
                     // not a component but a Maven object to be transformed into an expression/property
+                    getLogger().warn( "Deprecated @Component for " + pd.getName() + " field in "
+                                          + javaClass.getFullyQualifiedName() + ": replace with @Parameter( name = \""
+                                          + expression + "\", readonly = true )" );
                     pd.setDefaultValue( expression );
                     pd.setType( role );
                     pd.setRequired( true );
@@ -559,6 +560,13 @@ public class JavaMojoDescriptorExtractor
 
                 pd.setEditable( field.getTagByName( JavaMojoAnnotation.READONLY ) == null );
 
+                String name = parameter.getNamedParameter( JavaMojoAnnotation.PARAMETER_NAME );
+
+                if ( !StringUtils.isEmpty( name ) )
+                {
+                    pd.setName( name );
+                }
+
                 String alias = parameter.getNamedParameter( JavaMojoAnnotation.PARAMETER_ALIAS );
 
                 if ( !StringUtils.isEmpty( alias ) )
@@ -661,13 +669,6 @@ public class JavaMojoDescriptorExtractor
         return rawParams;
     }
 
-    /** {@inheritDoc} */
-    public List<MojoDescriptor> execute( MavenProject project, PluginDescriptor pluginDescriptor )
-        throws ExtractionException, InvalidPluginDescriptorException
-    {
-        return execute( new DefaultPluginToolsRequest( project, pluginDescriptor ) );
-    }
-    
     /** {@inheritDoc} */
     public List<MojoDescriptor> execute( PluginToolsRequest request )
         throws ExtractionException, InvalidPluginDescriptorException
